@@ -33,17 +33,17 @@
 #include <tqmap.h>
 
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
 #include <kinputdialog.h>
 #include <kicondialog.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kprocess.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <ktrader.h>
 #include <kxmlguifactory.h>
-#include <kparts/componentfactory.h>
+#include <tdeparts/componentfactory.h>
 
 #include "kaffeinedvbplugin.h"
 #include "dvbpanel.h"
@@ -64,7 +64,7 @@
 
 
 DIconViewItem::DIconViewItem( DvbPanel *pan, TQIconView *parent, const TQString &text, const TQPixmap &icon )
-	: KIconViewItem( parent, text, icon )
+	: TDEIconViewItem( parent, text, icon )
 {
 	panel = pan;
 }
@@ -83,7 +83,7 @@ void DIconViewItem::dropped( TQDropEvent *e, const TQValueList<TQIconDragItem> &
 
 
 
-DListView::DListView( TQWidget *parent ) : KListView( parent )
+DListView::DListView( TQWidget *parent ) : TDEListView( parent )
 {
 	visibleItems = 0;
 }
@@ -118,7 +118,7 @@ DvbPanel::DvbPanel( TQWidget *parent, TQObject *objParent, const char *name ) :
 	split = new TQSplitter( mainWidget );
 	split->setOpaqueResize( true );
 	pbox = new TQVBox( split );
-	iconView = new KIconView( pbox );
+	iconView = new TDEIconView( pbox );
 	iconView->setVScrollBarMode( TQScrollView::AlwaysOff );
 	iconView->setHScrollBarMode( TQScrollView::AlwaysOff );
 	iconView->horizontalScrollBar()->setFixedHeight( 0 );
@@ -233,23 +233,23 @@ DvbPanel::DvbPanel( TQWidget *parent, TQObject *objParent, const char *name ) :
 	h1->addItem( new TQSpacerItem( 1, 1, TQSizePolicy::Preferred, TQSizePolicy::Minimum ) );
 	vb->addLayout( h1 );
 
-	KIconLoader *icon = new KIconLoader();
-	tvPix = icon->loadIcon( "kdvbtv", KIcon::Small );
-	tvcPix = icon->loadIcon( "kdvbtvc", KIcon::Small );
-	raPix = icon->loadIcon( "kdvbra", KIcon::Small );
-	racPix = icon->loadIcon( "kdvbrac", KIcon::Small );
+	TDEIconLoader *icon = new TDEIconLoader();
+	tvPix = icon->loadIcon( "kdvbtv", TDEIcon::Small );
+	tvcPix = icon->loadIcon( "kdvbtvc", TDEIcon::Small );
+	raPix = icon->loadIcon( "kdvbra", TDEIcon::Small );
+	racPix = icon->loadIcon( "kdvbrac", TDEIcon::Small );
 	TQIconSet iconset;
-	iconset.setPixmap( icon->loadIcon( "filesave", KIcon::Small ), TQIconSet::Small );
-	iconset.setPixmap( icon->loadIcon( "player_record", KIcon::Small), TQIconSet::Small, TQIconSet::Normal, TQIconSet::On );
+	iconset.setPixmap( icon->loadIcon( "document-save", TDEIcon::Small ), TQIconSet::Small );
+	iconset.setPixmap( icon->loadIcon( "player_record", TDEIcon::Small), TQIconSet::Small, TQIconSet::Normal, TQIconSet::On );
 	recordBtn->setIconSet( iconset );
-	broadcastBtn->setIconSet( icon->loadIconSet("network_local", KIcon::Small) );
-	dateBtn->setIconSet( icon->loadIconSet("date", KIcon::Small) );
-	infoBtn->setIconSet( icon->loadIconSet("view_text", KIcon::Small) );
-	osdBtn->setIconSet( icon->loadIconSet("info", KIcon::Small) );
-	channelsBtn->setIconSet( icon->loadIconSet("kdvbtv", KIcon::Small) );
-	configBtn->setIconSet( icon->loadIconSet("configure", KIcon::Small) );
-	recallBtn->setIconSet( icon->loadIconSet("reload", KIcon::Small) );
-	searchBtn->setIconSet( icon->loadIconSet("locationbar_erase", KIcon::Small) );
+	broadcastBtn->setIconSet( icon->loadIconSet("network_local", TDEIcon::Small) );
+	dateBtn->setIconSet( icon->loadIconSet("date", TDEIcon::Small) );
+	infoBtn->setIconSet( icon->loadIconSet("view_text", TDEIcon::Small) );
+	osdBtn->setIconSet( icon->loadIconSet("application-vnd.tde.info", TDEIcon::Small) );
+	channelsBtn->setIconSet( icon->loadIconSet("kdvbtv", TDEIcon::Small) );
+	configBtn->setIconSet( icon->loadIconSet("configure", TDEIcon::Small) );
+	recallBtn->setIconSet( icon->loadIconSet("reload", TDEIcon::Small) );
+	searchBtn->setIconSet( icon->loadIconSet("locationbar_erase", TDEIcon::Small) );
 
 	setXMLFile("kaffeinedvb.rc");
 	setupActions();
@@ -435,19 +435,19 @@ bool DvbPanel::execTarget( const TQString &target )
 
 void DvbPanel::setupActions()
 {
-	new KAction(i18n("OSD Next Channel"), "next", CTRL+SHIFT+Key_W, this, TQT_SLOT(dvbOSDNext()), actionCollection(), "dvb_browse_next");
-	new KAction(i18n("OSD Previous Channel"), "previous", CTRL+SHIFT+Key_Q, this, TQT_SLOT(dvbOSDPrev()), actionCollection(),"dvb_browse_prev");
-	new KAction(i18n("OSD Zap"), "ok", CTRL+SHIFT+Key_E, this, TQT_SLOT(dvbOSDZap()), actionCollection(), "dvb_browse_zap");
-	new KAction(i18n("OSD Next Event"), "down", CTRL+SHIFT+Key_S, this, TQT_SLOT(dvbOSDAdvance()), actionCollection(), "dvb_browse_advance");
-	new KAction(i18n("OSD Previous Event"), "up", CTRL+SHIFT+Key_A, this, TQT_SLOT(dvbOSDRetreat()), actionCollection(), "dvb_browse_retreat");
-	new KAction(i18n("Instant Record"), "filesave", 0, this, TQT_SLOT(setRecord()), actionCollection(), "dvb_instant_record");
-	new KAction(i18n("Recall"), "reload", CTRL+SHIFT+Key_Z, this, TQT_SLOT(recallZap()), actionCollection(), "dvb_recall");
-	new KAction(i18n("Show OSD"), "info", Key_O, this, TQT_SLOT(dvbOSD()), actionCollection(), "dvb_show_osd");
-	new KAction(i18n("EPG..."), "view_text", Key_G, this, TQT_SLOT(showEvents()), actionCollection(), "dvb_show_epg");
-	new KAction(i18n("Timers..."), "date", Key_T, this, TQT_SLOT(showTimers()), actionCollection(), "dvb_show_timers");
-	new KAction(i18n("Broadcasting..."), "network_local", Key_B, this, TQT_SLOT(setBroadcast()), actionCollection(), "dvb_show_broadcast");
-	new KAction(i18n("Channels..."), "kdvbtv", Key_C, this, TQT_SLOT(scanner()), actionCollection(), "dvb_channels");
-	new KAction(i18n("Configure DVB..."), "configure", CTRL|Key_C, this, TQT_SLOT(showConfigDialog()), actionCollection(), "dvb_config");
+	new TDEAction(i18n("OSD Next Channel"), "go-next", CTRL+SHIFT+Key_W, this, TQT_SLOT(dvbOSDNext()), actionCollection(), "dvb_browse_next");
+	new TDEAction(i18n("OSD Previous Channel"), "go-previous", CTRL+SHIFT+Key_Q, this, TQT_SLOT(dvbOSDPrev()), actionCollection(),"dvb_browse_prev");
+	new TDEAction(i18n("OSD Zap"), "ok", CTRL+SHIFT+Key_E, this, TQT_SLOT(dvbOSDZap()), actionCollection(), "dvb_browse_zap");
+	new TDEAction(i18n("OSD Next Event"), "go-down", CTRL+SHIFT+Key_S, this, TQT_SLOT(dvbOSDAdvance()), actionCollection(), "dvb_browse_advance");
+	new TDEAction(i18n("OSD Previous Event"), "go-up", CTRL+SHIFT+Key_A, this, TQT_SLOT(dvbOSDRetreat()), actionCollection(), "dvb_browse_retreat");
+	new TDEAction(i18n("Instant Record"), "document-save", 0, this, TQT_SLOT(setRecord()), actionCollection(), "dvb_instant_record");
+	new TDEAction(i18n("Recall"), "reload", CTRL+SHIFT+Key_Z, this, TQT_SLOT(recallZap()), actionCollection(), "dvb_recall");
+	new TDEAction(i18n("Show OSD"), "application-vnd.tde.info", Key_O, this, TQT_SLOT(dvbOSD()), actionCollection(), "dvb_show_osd");
+	new TDEAction(i18n("EPG..."), "view_text", Key_G, this, TQT_SLOT(showEvents()), actionCollection(), "dvb_show_epg");
+	new TDEAction(i18n("Timers..."), "date", Key_T, this, TQT_SLOT(showTimers()), actionCollection(), "dvb_show_timers");
+	new TDEAction(i18n("Broadcasting..."), "network_local", Key_B, this, TQT_SLOT(setBroadcast()), actionCollection(), "dvb_show_broadcast");
+	new TDEAction(i18n("Channels..."), "kdvbtv", Key_C, this, TQT_SLOT(scanner()), actionCollection(), "dvb_channels");
+	new TDEAction(i18n("Configure DVB..."), "configure", CTRL|Key_C, this, TQT_SLOT(showConfigDialog()), actionCollection(), "dvb_config");
 }
 
 
@@ -580,15 +580,15 @@ void DvbPanel::catContextMenu( TQIconViewItem *it, const TQPoint &p )
 					ok = false;
 			}
 			if ( ok ) {
-				KIconViewItem* item = new DIconViewItem(this, iconView, name, KGlobal::iconLoader()->loadIcon("kaffeine", KIcon::NoGroup, KIcon::SizeSmallMedium));
+				TDEIconViewItem* item = new DIconViewItem(this, iconView, name, TDEGlobal::iconLoader()->loadIcon("kaffeine", TDEIcon::NoGroup, TDEIcon::SizeSmallMedium));
 				item->setDropEnabled( true );
 				dvbConfig->addCategory( name, "kaffeine" );
 			}
 			break;
 		case 1 :
-			icon = KIconDialog::getIcon();
+			icon = TDEIconDialog::getIcon();
 			if ( !icon.isEmpty() ) {
-				it->setPixmap( KGlobal::iconLoader()->loadIcon(icon, KIcon::NoGroup, KIcon::SizeSmallMedium) );
+				it->setPixmap( TDEGlobal::iconLoader()->loadIcon(icon, TDEIcon::NoGroup, TDEIcon::SizeSmallMedium) );
 				dvbConfig->changeIconCategory( it->text(), icon );
 			}
 			break;
@@ -1022,21 +1022,21 @@ void DvbPanel::setConfig()
 {
 	int i;
 	int error = 0;
-	KIconViewItem* item = NULL;
+	TDEIconViewItem* item = NULL;
 	DvbStream *d;
 
 	TQString s = locateLocal("appdata", "");
 	dvbConfig = new DVBconfig( s );
-	item = new DIconViewItem(this, iconView, i18n("All"), KGlobal::iconLoader()->loadIcon(dvbConfig->allIcon, KIcon::NoGroup, KIcon::SizeSmallMedium));
+	item = new DIconViewItem(this, iconView, i18n("All"), TDEGlobal::iconLoader()->loadIcon(dvbConfig->allIcon, TDEIcon::NoGroup, TDEIcon::SizeSmallMedium));
 	iconView->setFixedHeight( item->height()+iconView->horizontalScrollBar()->height() );
 	item->setDropEnabled( true );
-	item = new DIconViewItem(this, iconView, i18n("Radio"), KGlobal::iconLoader()->loadIcon(dvbConfig->radioIcon, KIcon::NoGroup, KIcon::SizeSmallMedium));
+	item = new DIconViewItem(this, iconView, i18n("Radio"), TDEGlobal::iconLoader()->loadIcon(dvbConfig->radioIcon, TDEIcon::NoGroup, TDEIcon::SizeSmallMedium));
 	item->setDropEnabled( false );
-	item = new DIconViewItem(this, iconView, i18n("TV"), KGlobal::iconLoader()->loadIcon(dvbConfig->tvIcon, KIcon::NoGroup, KIcon::SizeSmallMedium));
+	item = new DIconViewItem(this, iconView, i18n("TV"), TDEGlobal::iconLoader()->loadIcon(dvbConfig->tvIcon, TDEIcon::NoGroup, TDEIcon::SizeSmallMedium));
 	item->setDropEnabled( false );
 
-	KTrader::OfferList offers = KTrader::self()->query("KaffeineDvbPlugin");
-	KTrader::OfferList::Iterator it = offers.begin();
+	TDETrader::OfferList offers = TDETrader::self()->query("KaffeineDvbPlugin");
+	TDETrader::OfferList::Iterator it = offers.begin();
 	if ( it!=offers.end() ) {
 		KService::Ptr ptr = (*it);
 		plugName = ptr->desktopEntryName();
@@ -1051,7 +1051,7 @@ void DvbPanel::setConfig()
 	}
 
 	for ( i=0; i<(int)dvbConfig->categories.count(); i++ ) {
-		item = new DIconViewItem(this, iconView, dvbConfig->categories.at(i)->name, KGlobal::iconLoader()->loadIcon(dvbConfig->categories.at(i)->icon, KIcon::NoGroup, KIcon::SizeSmallMedium));
+		item = new DIconViewItem(this, iconView, dvbConfig->categories.at(i)->name, TDEGlobal::iconLoader()->loadIcon(dvbConfig->categories.at(i)->icon, TDEIcon::NoGroup, TDEIcon::SizeSmallMedium));
 		item->setDropEnabled( true );
 	}
 
@@ -1065,7 +1065,7 @@ void DvbPanel::setConfig()
 		connect( d, TQT_SIGNAL(isRecording(bool)), this, TQT_SLOT(setRecordLed(bool)) );
 		connect( d, TQT_SIGNAL(playDvb()), this, TQT_SLOT(pipeOpened()) );
 	}
-	fifoName = KGlobal::dirs()->saveLocation("tmp")+".kaxtv.ts";
+	fifoName = TDEGlobal::dirs()->saveLocation("tmp")+".kaxtv.ts";
 	TQFile f( fifoName );
 	if ( f.exists() )
 		f.remove();
@@ -1073,7 +1073,7 @@ void DvbPanel::setConfig()
 		perror( fifoName.latin1() );
 		fifoName = "";
 	}
-	fifoName1 = KGlobal::dirs()->saveLocation("tmp")+".kaxtv1.ts";
+	fifoName1 = TDEGlobal::dirs()->saveLocation("tmp")+".kaxtv1.ts";
 	TQFile f1( fifoName1 );
 	if ( f1.exists() )
 		f1.remove();
@@ -1161,7 +1161,7 @@ void DvbPanel::fillChannelList( ChannelDesc *ch )
 {
 	int i, j;
 	ChannelDesc *chan;
-	KListViewItem *it, *visible=0;
+	TDEListViewItem *it, *visible=0;
 	bool cont=false;
 	TQPtrList<Transponder> trans = getSourcesStatus();
 	trans.setAutoDelete( true );
@@ -1193,7 +1193,7 @@ void DvbPanel::fillChannelList( ChannelDesc *ch )
 		}
 		else if ( currentCategory!="All" && chan->category!=currentCategory )
 			continue;
-		it = new KListViewItem( channelsCb, TQString().sprintf("%05d", chan->num), chan->name, chan->tp.source );
+		it = new TDEListViewItem( channelsCb, TQString().sprintf("%05d", chan->num), chan->name, chan->tp.source );
 		if ( ch && ch==chan )
 			visible = it;
 		it->setDragEnabled( true );
@@ -1349,10 +1349,10 @@ void DvbPanel::checkTimers()
 					emit dvbStop();
 				}
 				if ( d->startTimer( chan, dvbConfig->recordDir, dvbConfig->sizeFile, t, dvbConfig->filenameFormat ) ) {
-					KProcess proc;
+					TDEProcess proc;
 					proc << TQDir::homeDirPath()+"/bin/kaffeine_recording";
 					proc << "On";
-					proc.start( KProcess::DontCare );
+					proc.start( TDEProcess::DontCare );
 					t->running = 1;
 					if ( timersDialog )
 						emit timersChanged();
@@ -1423,10 +1423,10 @@ void DvbPanel::setRecord()
 	ret = d->canStartTimer( live, &curchan );
 	if ( ret==0 ) {
 		if ( d->startTimer( &curchan, dvbConfig->recordDir, dvbConfig->sizeFile, rt, dvbConfig->filenameFormat ) ) {
-			KProcess proc;
+			TDEProcess proc;
 			proc << TQDir::homeDirPath()+"/bin/kaffeine_recording";
 			proc << "On";
-			proc.start( KProcess::DontCare );
+			proc.start( TDEProcess::DontCare );
 
 			for ( i=0; i<(int)timers.count(); i++ ) {
 				t = timers.at(i);
@@ -1526,14 +1526,14 @@ void DvbPanel::killTimer( RecTimer *t )
 
 	for ( i=0; i<(int)timers.count(); i++ ) {
 		if ( timers.at(i)==t ) {
-			KProcess proc;
+			TDEProcess proc;
 			proc << TQDir::homeDirPath()+"/bin/kaffeine_recording";
 			if ( recordLed->state()==KLed::On )
 				proc << "On";
 			else
 				proc << "Off";
-			proc << KProcess::quote( t->fullPath );
-			proc.start( KProcess::DontCare );
+			proc << TDEProcess::quote( t->fullPath );
+			proc.start( TDEProcess::DontCare );
 
 			if ( t->mode )
 				updateModeTimer( t );
@@ -2123,7 +2123,7 @@ bool DvbPanel::getChannelList()
 	ChannelDesc *chan;
 	TQString src="";
 	int ns;
-	KListViewItem *it;
+	TDEListViewItem *it;
 	TQPixmap pix;
 
 	maxChannelNumber = 0;
@@ -2377,7 +2377,7 @@ bool DvbPanel::getChannelList()
 			}
 
 			chan->pix.load( dvbConfig->dvbConfigIconsDir+chan->name );
-			it = new KListViewItem( channelsCb, TQString().sprintf("%05d", chan->num), chan->name, chan->tp.source );
+			it = new TDEListViewItem( channelsCb, TQString().sprintf("%05d", chan->num), chan->name, chan->tp.source );
 			it->setDragEnabled( true );
 			if ( !chan->pix.isNull() )
 				it->setPixmap( 1, chan->pix );
